@@ -63,6 +63,12 @@ def evaluate_mutations(self, reports: list) -> list:
 
     # If we found a new path
     if len(self.reached_instructions) > start_reached_instructions_count:
+        # Save coverage increase report
+        if self.config.FRELATAGE_SAVE_NEW_COVERAGE:
+            self.save_report(report, crash=False)
+        self.unique_coverage_increase += 1
+
+        # Update stats
         self.last_new_path_time = datetime.now()
         self.cycles_without_new_path = 0
     else:
